@@ -115,6 +115,9 @@ def main_options(parser):
     parser.add_argument('--constant_rate_factor', '-crf', default='unset',
         group='exportMediaOps', range='0 to 51',
         help='set the quality for video using the crf method.')
+    parser.add_argument('--has_vfr', default='unset', group='exportMediaOps',
+        choices=['unset', 'yes', 'no'],
+        help='skip variable frame rate scan, saving time for big video files.')
 
     parser.add_argument('--render', default='auto', choices=['av', 'opencv', 'auto'],
         help='choice which method to render video.')
@@ -144,6 +147,8 @@ def main_options(parser):
     parser.add_argument('--cut_out', type=range_type, nargs='*',
         help='the range of media that will be removed completely, regardless of the '\
             'value of silent speed.')
+    parser.add_argument('--add_in', type=range_type, nargs='*',
+        help='the range of media that will be added in, opposite of --cut_out')
     parser.add_argument('--set_speed_for_range', type=speed_range_type, nargs='*',
         help='set an arbitrary speed for a given range.',
         extra='The arguments are: speed,start,end')
@@ -152,9 +157,9 @@ def main_options(parser):
         range='0 to 1',
         help='how much motion is required to be considered "moving"')
     parser.add_argument('--edit_based_on', '--edit', default='audio',
-        choices=['audio', 'motion', 'none', 'not_audio', 'not_motion', 'audio_or_motion',
-            'audio_and_motion', 'audio_xor_motion', 'audio_and_not_motion',
-            'not_audio_and_motion', 'not_audio_and_not_motion'],
+        choices=['audio', 'motion', 'none', 'all', 'not_audio', 'not_motion',
+            'audio_or_motion', 'audio_and_motion', 'audio_xor_motion',
+            'audio_and_not_motion', 'not_audio_and_motion', 'not_audio_and_not_motion'],
         help='decide which method to use when making edits.')
 
     parser.add_argument('--cut_by_this_audio', '-ca', type=file_type,
@@ -233,62 +238,68 @@ def main_options(parser):
     return parser
 
 
-def get_chunks(inp, speeds, segment, fps, args, log, audioData=None, sampleRate=None):
+def get_chunks(inp, speeds, segment, fps, args, log, audio_samples=None, sample_rate=None):
     from auto_editor.cutting import (combine_audio_motion, combine_segment,
-        apply_spacing_rules, apply_frame_margin, seconds_to_frames, cook, chunkify)
+        apply_spacing_rules, apply_mark_as, apply_frame_margin, seconds_to_frames, cook, chunkify)
 
     frame_margin = seconds_to_frames(args.frame_margin, fps)
     min_clip = seconds_to_frames(args.min_clip_length, fps)
     min_cut = seconds_to_frames(args.min_cut_length, fps)
 
-    def get_has_loud(inp, args, fps, audioData, sampleRate, log):
-        from auto_editor.analyze import get_blank_list, audio_detection, motion_detection
+    def get_has_loud(inp, args, fps, audio_samples, sample_rate, log):
+        import numpy as np
+        from auto_editor.analyze import get_np_list, audio_detection, motion_detection
         if(args.edit_based_on == 'none'):
-            return get_blank_list(inp, audioData, sampleRate, fps)
+            return get_np_list(inp, audio_samples, sample_rate, fps, np.ones)
+        if(args.edit_based_on == 'all'):
+            return get_np_list(inp, audio_samples, sample_rate, fps, np.zeros)
 
-        audioList, motionList = None, None
+        audio_list, motion_list = None, None
 
         if('audio' in args.edit_based_on):
-            if(audioData is None):
-                audioList = get_blank_list(inp, audioData, sampleRate, fps)
+            if(audio_samples is None):
+                audio_list = get_np_list(inp, audio_samples, sample_rate, fps, np.ones)
             else:
-                audioList = audio_detection(audioData, sampleRate, args.silent_threshold,
-                    fps, log)
+                audio_list = audio_detection(audio_samples, sample_rate,
+                    args.silent_threshold, fps, log)
 
         if('motion' in args.edit_based_on):
             if(len(inp.video_streams) == 0):
-                motionList = get_blank_list(inp, audioData, sampleRate, fps)
+                motion_list = get_np_list(inp, audio_samples, sample_rate, fps, np.ones)
             else:
-                motionList = motion_detection(inp, args.motion_threshold, log,
+                motion_list = motion_detection(inp, args.motion_threshold, log,
                     width=args.width, dilates=args.dilates, blur=args.blur)
 
-        if(audioList is not None and motionList is not None):
-            if(len(audioList) > len(motionList)):
-                audioList = audioList[:len(motionList)]
-            elif(len(motionList) > len(audioList)):
-                motionList = motionList[:len(audioList)]
+        if(audio_list is not None and motion_list is not None):
+            if(len(audio_list) > len(motion_list)):
+                audio_list = audio_list[:len(motion_list)]
+            elif(len(motion_list) > len(audio_list)):
+                motion_list = motion_list[:len(audio_list)]
 
-        return combine_audio_motion(audioList, motionList, args.edit_based_on, log)
+        return combine_audio_motion(audio_list, motion_list, args.edit_based_on, log)
 
-    has_loud = get_has_loud(inp, args, fps, audioData, sampleRate, log)
-    has_loud = cook(has_loud, min_clip, min_cut)
+    has_loud = get_has_loud(inp, args, fps, audio_samples, sample_rate, log)
     has_loud_length = len(has_loud)
+    has_loud = apply_mark_as(has_loud, has_loud_length, fps, args, log)
+    has_loud = cook(has_loud, min_clip, min_cut)
     has_loud = apply_frame_margin(has_loud, has_loud_length, frame_margin)
 
     if(segment is not None):
         has_loud = combine_segment(has_loud, segment, fps)
+    # Remove small clips/cuts created by applying other rules.
+    has_loud = cook(has_loud, min_clip, min_cut)
     return apply_spacing_rules(has_loud, has_loud_length, min_clip, min_cut, speeds,
         fps, args, log)
 
 
-def get_effects(audioData, sampleRate, fps, args, log):
+def get_effects(audio_samples, sample_rate, fps, args, log):
     effects = []
     if(args.zoom != []):
         from auto_editor.cutting import applyZooms
-        effects += applyZooms(args.zoom, audioData, sampleRate, fps, log)
+        effects += applyZooms(args.zoom, audio_samples, sample_rate, fps, log)
     if(args.rectangle != []):
         from auto_editor.cutting import applyRects
-        effects += applyRects(args.rectangle, audioData, sampleRate, fps, log)
+        effects += applyRects(args.rectangle, audio_samples, sample_rate, fps, log)
     return effects
 
 def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_file,
@@ -297,22 +308,20 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
     if(inp.ext == '.json'):
         from auto_editor.formats.make_json import read_json_cutlist
 
-        INPUT_FILE, chunks, speeds = read_json_cutlist(inp.path, auto_editor.version, log)
+        input_path, chunks, speeds = read_json_cutlist(inp.path, auto_editor.version, log)
+        inp = ffmpeg.file_info(input_path)
 
-        inp = ffmpeg.file_info(INPUT_FILE)
-
-        newOutput = set_output_name(inp.path, data_file, args)
+        output_path = set_output_name(inp.path, data_file, args)
     else:
-        newOutput = args.output_file[i]
-        if(not os.path.isdir(inp.path) and '.' not in newOutput):
-            newOutput = set_output_name(newOutput, data_file, args)
+        output_path = args.output_file[i]
+        if(not os.path.isdir(inp.path) and '.' not in output_path):
+            output_path = set_output_name(output_path, data_file, args)
 
-    log.debug('Input File: {}'.format(inp.path))
-    log.debug('Output File: {}'.format(newOutput))
+    log.debug('{} -> {}'.format(inp.path, output_path))
 
-    if(os.path.isfile(newOutput) and inp.path != newOutput):
-        log.debug('Removing already existing file: {}'.format(newOutput))
-        os.remove(newOutput)
+    if(os.path.isfile(output_path) and inp.path != output_path):
+        log.debug('Removing already existing file: {}'.format(output_path))
+        os.remove(output_path)
 
     def user_sample_rate(args_sample, inp):
         # type: (int | str | None, Any) -> str | None
@@ -323,27 +332,26 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
         return str(args_sample)
 
 
-    sampleRate = user_sample_rate(args.sample_rate, inp)
-    log.debug('Samplerate: {}'.format(sampleRate))
+    sample_rate = user_sample_rate(args.sample_rate, inp)
+    log.debug('Samplerate: {}'.format(sample_rate))
 
-    audioData = None
-    audioExtensions = ['.wav', '.mp3', '.m4a', '.aiff', '.flac', '.ogg', '.oga',
-        '.acc', '.nfa', '.mka']
-    audioFile = inp.ext in audioExtensions
-    if(audioFile):
+    audio_samples = None
+    audio_file = len(inp.video_streams) == 0 and len(inp.audio_streams) > 0
+    tracks = len(inp.audio_streams)
+
+    if(audio_file):
         fps = 30 if args.force_fps_to is None else args.force_fps_to
-        tracks = 1
 
         temp_file = os.path.join(TEMP, 'fastAud.wav')
 
         cmd = ['-i', inp.path]
         if(not fnone(args.audio_bitrate)):
             cmd.extend(['-b:a', args.audio_bitrate])
-        cmd.extend(['-ac', '2', '-ar', sampleRate, '-vn', temp_file])
+        cmd.extend(['-ac', '2', '-ar', sample_rate, '-vn', temp_file])
         ffmpeg.run(cmd)
 
         from auto_editor.scipy.wavfile import read
-        sampleRate, audioData = read(temp_file)
+        sample_rate, audio_samples = read(temp_file)
     else:
         if(args.force_fps_to is not None):
             fps = args.force_fps_to
@@ -356,8 +364,6 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
             log.error('{}: Frame rate cannot be below 1. fps: {}'.format(
                 inp.basename, fps))
 
-        tracks = len(inp.audio_streams)
-
         if(args.cut_by_this_track >= tracks and 'cut_by_this_track' in args._set):
             message = "You choose a track that doesn't exist.\nThere "
             if(tracks == 1):
@@ -368,7 +374,7 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
                 message += ' Track {}\n'.format(t)
             log.error(message)
 
-        def NumberOfVrfFrames(text, log):
+        def number_of_VFR_frames(text, log):
             import re
             search = re.search(r'VFR:[\d.]+ \(\d+\/\d+\)', text, re.M)
             if(search is None):
@@ -376,11 +382,20 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
                 return 0
             else:
                 nums = re.search(r'\d+\/\d+', search.group()).group(0)
-                log.debug(nums)
+                log.debug('VFR Frames: {}'.format(nums))
                 return int(nums.split('/')[0])
 
-        def hasVFR(cmd, log):
-            return NumberOfVrfFrames(ffmpeg.pipe(cmd), log) != 0
+        def has_VFR(cmd, log):
+            return number_of_VFR_frames(ffmpeg.pipe(cmd), log) != 0
+
+        # Extract subtitles in their native format.
+        if(len(inp.subtitle_streams) > 0):
+            cmd = ['-i', inp.path, '-hide_banner']
+            for s, sub in enumerate(inp.subtitle_streams):
+                cmd.extend(['-map', '0:s:{}'.format(s)])
+            for s, sub in enumerate(inp.subtitle_streams):
+                cmd.extend([os.path.join(TEMP, '{}s.{}'.format(s, sub['ext']))])
+            ffmpeg.run(cmd)
 
         # Split audio tracks into: 0.wav, 1.wav, etc.
         cmd = ['-i', inp.path, '-hide_banner']
@@ -388,56 +403,66 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
             cmd.extend(['-map', '0:a:{}'.format(t)])
             if(not fnone(args.audio_bitrate)):
                 cmd.extend(['-ab', args.audio_bitrate])
-            cmd.extend(['-ac', '2', '-ar', sampleRate,
+            cmd.extend(['-ac', '2', '-ar', sample_rate,
                 os.path.join(TEMP, '{}.wav'.format(t))])
-        cmd.extend(['-map', '0:v:0', '-vf', 'vfrdet', '-f', 'null', '-'])
-        has_vfr = hasVFR(cmd, log)
+        cmd.extend(['-map', '0:v:0'])
+        if(args.has_vfr == 'unset'):
+            cmd.extend(['-vf', 'vfrdet', '-f', 'null', '-'])
+            has_vfr = has_VFR(cmd, log)
+        else:
+            ffmpeg.run(cmd)
+            has_vfr = args.has_vfr == 'yes'
         del cmd
 
         if(len(inp.video_streams) > 0 and tracks == 0):
             # Doesn't matter because we don't need to align to an audio track.
             has_vfr = False
 
+        log.debug('Has VFR: {}'.format(has_vfr))
+
         if(tracks != 0):
             if(args.cut_by_all_tracks):
                 temp_file = os.path.join(TEMP, 'combined.wav')
                 cmd = ['-i', inp.path, '-filter_complex',
                     '[0:a]amix=inputs={}:duration=longest'.format(tracks), '-ar',
-                    sampleRate, '-ac', '2', '-f', 'wav', temp_file]
+                    sample_rate, '-ac', '2', '-f', 'wav', temp_file]
                 ffmpeg.run(cmd)
                 del cmd
             else:
                 temp_file = os.path.join(TEMP, '{}.wav'.format(args.cut_by_this_track))
 
             from auto_editor.scipy.wavfile import read
-            sampleRate, audioData = read(temp_file)
+            sample_rate, audio_samples = read(temp_file)
 
     log.debug('Frame Rate: {}'.format(fps))
     if(chunks is None):
-        chunks = get_chunks(inp, speeds, segment, fps, args, log, audioData, sampleRate)
-        effects = get_effects(audioData, sampleRate, fps, args, log)
+        chunks = get_chunks(inp, speeds, segment, fps, args, log, audio_samples,
+            sample_rate)
+        effects = get_effects(audio_samples, sample_rate, fps, args, log)
 
-    def isClip(chunk):
+    def is_clip(chunk):
+        # type: (list) -> bool
         return speeds[chunk[2]] != 99999
 
-    def getNumberOfCuts(chunks, speeds):
-        return len(list(filter(isClip, chunks)))
+    def number_of_cuts(chunks, speeds):
+        # type: (list, list) -> int
+        return len(list(filter(is_clip, chunks)))
 
-    def getClips(chunks, speeds):
+    def get_clips(chunks, speeds):
         clips = []
         for chunk in chunks:
-            if(isClip(chunk)):
+            if(is_clip(chunk)):
                 clips.append([chunk[0], chunk[1], speeds[chunk[2]] * 100])
         return clips
 
-    num_cuts = getNumberOfCuts(chunks, speeds)
-    clips = getClips(chunks, speeds)
+    num_cuts = number_of_cuts(chunks, speeds)
+    clips = get_clips(chunks, speeds)
 
     if(args.export_as_json):
         from auto_editor.formats.make_json import make_json_cutlist
-        make_json_cutlist(inp.path, newOutput, auto_editor.version, chunks, speeds,
+        make_json_cutlist(inp.path, output_path, auto_editor.version, chunks, speeds,
             log)
-        return num_cuts, newOutput
+        return num_cuts, output_path
 
     if(args.preview):
         from auto_editor.preview import preview
@@ -446,50 +471,55 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
 
     if(args.export_to_premiere):
         from auto_editor.formats.premiere import premiere_xml
-        premiere_xml(inp, TEMP, newOutput, clips, chunks, sampleRate, audioFile,
+        premiere_xml(inp, TEMP, output_path, clips, chunks, sample_rate, audio_file,
             fps, log)
-        return num_cuts, newOutput
+        return num_cuts, output_path
 
     if(args.export_to_final_cut_pro or args.export_to_resolve):
         from auto_editor.formats.final_cut_pro import fcp_xml
 
         totalFrames = chunks[len(chunks) - 1][1]
-        fcp_xml(inp, TEMP, newOutput, clips, tracks, totalFrames, audioFile, fps, log)
-        return num_cuts, newOutput
+        fcp_xml(inp, TEMP, output_path, clips, tracks, totalFrames, audio_file, fps, log)
+        return num_cuts, output_path
 
     if(args.export_to_shotcut):
         from auto_editor.formats.shotcut import shotcut_xml
 
-        shotcut_xml(inp, TEMP, newOutput, clips, chunks, fps, log)
-        return num_cuts, newOutput
+        shotcut_xml(inp, TEMP, output_path, clips, chunks, fps, log)
+        return num_cuts, output_path
 
-    def makeAudioFile(inp, chunks, output):
-        from auto_editor.render.audio import fastAudio, handleAudio, convertAudio
-        theFile = handleAudio(ffmpeg, inp.path, args.audio_bitrate, str(sampleRate),
+    def make_audio(inp, chunks, output_path):
+        from auto_editor.render.audio import make_new_audio, handle_audio, convert_audio
+        the_file = handle_audio(ffmpeg, inp.path, args.audio_bitrate, str(sample_rate),
             TEMP, log)
 
         temp_file = os.path.join(TEMP, 'convert.wav')
-        fastAudio(theFile, temp_file, chunks, speeds, log, fps,
+        make_new_audio(the_file, temp_file, chunks, speeds, log, fps,
             args.machine_readable_progress, args.no_progress)
-        convertAudio(ffmpeg, temp_file, inp, output, args.audio_codec, log)
+        convert_audio(ffmpeg, temp_file, inp, output_path, args.audio_codec, log)
 
-    if(audioFile):
+    if(audio_file):
         if(args.export_as_clip_sequence):
             i = 1
             for item in chunks:
                 if(speeds[item[2]] == 99999):
                     continue
-                makeAudioFile(inp, [item], append_filename(newOutput, '-{}'.format(i)))
+                make_audio(inp, [item], append_filename(output_path, '-{}'.format(i)))
                 i += 1
         else:
-            makeAudioFile(inp, chunks, newOutput)
-        return num_cuts, newOutput
+            make_audio(inp, chunks, output_path)
+        return num_cuts, output_path
 
-    def makeVideoFile(inp, chunks, output):
-        from auto_editor.utils.video import handleAudioTracks, mux_rename_video
-        continueVid = handleAudioTracks(ffmpeg, output, args, tracks, chunks,
+    def make_video_file(inp, chunks, output_path):
+        from auto_editor.utils.video import handle_audio_tracks, mux_rename_video
+
+        if(len(inp.subtitle_streams) > 0):
+            from auto_editor.render.subtitle import cut_subtitles
+            cut_subtitles(ffmpeg, inp, chunks, speeds, fps, TEMP, log)
+
+        continue_video = handle_audio_tracks(ffmpeg, output_path, args, tracks, chunks,
             speeds, fps, TEMP, log)
-        if(continueVid):
+        if(continue_video):
             if(args.render == 'auto'):
                 if(args.zoom != [] or args.rectangle != []):
                     args.render = 'opencv'
@@ -511,11 +541,12 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
                         'av render method.')
 
                 from auto_editor.render.av import render_av
-                render_av(ffmpeg, inp, args, chunks, speeds, fps, has_vfr, TEMP, log)
+                spedup = render_av(ffmpeg, inp, args, chunks, speeds, fps, has_vfr,
+                    TEMP, log)
 
             if(args.render == 'opencv'):
                 from auto_editor.render.opencv import render_opencv
-                render_opencv(ffmpeg, inp, args, chunks, speeds, fps, has_vfr,
+                spedup = render_opencv(ffmpeg, inp, args, chunks, speeds, fps, has_vfr,
                     effects, TEMP, log)
 
             if(log.is_debug):
@@ -523,19 +554,19 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
             else:
                 log.conwrite('Writing the output file.')
 
-            mux_rename_video(ffmpeg, output, args, tracks, TEMP, log)
-            if(output is not None and not os.path.isfile(output)):
-                log.bug('The file {} was not created.'.format(output))
+            mux_rename_video(ffmpeg, spedup, output_path, args, inp, TEMP, log)
+            if(output_path is not None and not os.path.isfile(output_path)):
+                log.bug('The file {} was not created.'.format(output_path))
 
     if(args.export_as_clip_sequence):
 
-        def pad_chunk(item, totalFrames):
+        def pad_chunk(item, total_frames):
             start = None
             end = None
             if(item[0] != 0):
                 start = [0, item[0], 2]
-            if(item[1] != totalFrames -1):
-                end = [item[1], totalFrames -1, 2]
+            if(item[1] != total_frames -1):
+                end = [item[1], total_frames -1, 2]
 
             if(start is None):
                 return [item] + [end]
@@ -550,12 +581,12 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
             if(speeds[chunk[2]] == 99999):
                 continue
 
-            makeVideoFile(inp, pad_chunk(chunk, totalFrames),
-                append_filename(newOutput, '-{}'.format(i)))
+            make_video_file(inp, pad_chunk(chunk, totalFrames),
+                append_filename(output_path, '-{}'.format(i)))
             i += 1
     else:
-        makeVideoFile(inp, chunks, newOutput)
-    return num_cuts, newOutput
+        make_video_file(inp, chunks, output_path)
+    return num_cuts, output_path
 
 
 def main():
@@ -573,19 +604,9 @@ def main():
     subcommands = ['create', 'test', 'info', 'levels', 'grep']
 
     if(len(sys.argv) > 1 and sys.argv[1] in subcommands):
-        if(sys.argv[1] == 'create'):
-            from auto_editor.subcommands.create import create as sub
-        if(sys.argv[1] == 'test'):
-            from auto_editor.subcommands.test import test as sub
-        if(sys.argv[1] == 'info'):
-            from auto_editor.subcommands.info import info as sub
-        if(sys.argv[1] == 'levels'):
-            from auto_editor.subcommands.levels import levels as sub
-        if(sys.argv[1] == 'grep'):
-            from auto_editor.subcommands.grep import grep as sub
-
-        sub(sys.argv[2:])
-
+        obj = __import__('auto_editor.subcommands.{}'.format(sys.argv[1]),
+            fromlist=['subcommands'])
+        obj.main(sys.argv[2:])
         sys.exit()
     else:
         parser = main_options(parser)
@@ -609,7 +630,7 @@ def main():
         print('Platform: {} {}'.format(platform.system(), platform.release()))
         print('Config File path: {}'.format(os.path.join(dir_path, 'config.txt')))
         print('FFmpeg path: {}'.format(ffmpeg.getPath()))
-        print('FFmpeg version: {}'.format(ffmpeg.getVersion()))
+        print('FFmpeg version: {}'.format(ffmpeg.version()))
         print('Auto-Editor version {}'.format(auto_editor.version))
         sys.exit()
 
@@ -694,22 +715,22 @@ def main():
         args.output_file = []
 
     from auto_editor.validateInput import valid_input
-    inputList, segments = valid_input(args.input, ffmpeg, args, log)
+    input_list, segments = valid_input(args.input, ffmpeg, args, log)
 
-    if(len(args.output_file) < len(inputList)):
-        for i in range(len(inputList) - len(args.output_file)):
-            args.output_file.append(set_output_name(inputList[i], making_data_file, args))
+    if(len(args.output_file) < len(input_list)):
+        for i in range(len(input_list) - len(args.output_file)):
+            args.output_file.append(set_output_name(input_list[i], making_data_file, args))
 
     if(args.combine_files):
         temp_file = os.path.join(TEMP, 'combined.mp4')
         cmd = []
-        for fileref in inputList:
+        for fileref in input_list:
             cmd.extend(['-i', fileref])
-        cmd.extend(['-filter_complex', '[0:v]concat=n={}:v=1:a=1'.format(len(inputList)),
+        cmd.extend(['-filter_complex', '[0:v]concat=n={}:v=1:a=1'.format(len(input_list)),
             '-codec:v', 'h264', '-pix_fmt', 'yuv420p', '-strict', '-2', temp_file])
         ffmpeg.run(cmd)
         del cmd
-        inputList = [temp_file]
+        input_list = [temp_file]
 
     speeds = [args.silent_speed, args.video_speed]
     if(args.cut_out != [] and 99999 not in speeds):
@@ -721,16 +742,16 @@ def main():
 
     log.debug('Speeds: {}'.format(speeds))
 
-    def main_loop(inputList, ffmpeg, args, speeds, segments, log):
+    def main_loop(input_list, ffmpeg, args, speeds, segments, log):
         num_cuts = 0
 
-        for i, INPUT_FILE in enumerate(inputList):
-            inp = ffmpeg.file_info(INPUT_FILE)
+        for i, input_path in enumerate(input_list):
+            inp = ffmpeg.file_info(input_path)
 
-            if(len(inputList) > 1):
+            if(len(input_list) > 1):
                 log.conwrite('Working on {}'.format(inp.basename))
 
-            cuts, newOutput = edit_media(i, inp, ffmpeg, args, speeds, segments[i],
+            cuts, output_path = edit_media(i, inp, ffmpeg, args, speeds, segments[i],
                 exporting_to_editor, making_data_file, TEMP, log)
             num_cuts += cuts
 
@@ -746,10 +767,10 @@ def main():
                 'edited manually.'.format(num_cuts, s, time_save))
 
         if(not args.no_open):
-            usefulfunctions.open_with_system_default(newOutput, log)
+            usefulfunctions.open_with_system_default(output_path, log)
 
     try:
-        main_loop(inputList, ffmpeg, args, speeds, segments, log)
+        main_loop(input_list, ffmpeg, args, speeds, segments, log)
     except KeyboardInterrupt:
         log.error('Keyboard Interrupt')
     log.cleanup()
