@@ -3,7 +3,7 @@
 from __future__ import print_function
 
 def info_options(parser):
-    parser.add_argument('--include_vfr', action='store_true',
+    parser.add_argument('--include_vfr', '--has_vfr', action='store_true',
         help='skip information that is very slow to get.')
     parser.add_argument('--ffmpeg_location', default=None,
         help='point to your custom ffmpeg file.')
@@ -15,14 +15,14 @@ def info_options(parser):
         help='the path to a file you want inspected.')
     return parser
 
-def info(sys_args=None):
+def main(sys_args=None):
     import os
     import sys
 
     import auto_editor
     import auto_editor.vanparse as vanparse
 
-    from auto_editor.utils.func import clean_list, aspect_ratio
+    from auto_editor.utils.func import aspect_ratio
     from auto_editor.utils.log import Log
 
     from auto_editor.ffwrapper import FFmpeg
@@ -68,21 +68,23 @@ def info(sys_args=None):
             text += ' - video codec: {}\n'.format(inp.video_streams[0]['codec'])
             text += ' - video bitrate: {}\n'.format(inp.video_streams[0]['bitrate'])
 
-            tracks = len(inp.audio_streams)
-            text += ' - audio tracks: {}\n'.format(tracks)
+            audio_tracks = len(inp.audio_streams)
+            text += ' - audio tracks: {}\n'.format(audio_tracks)
 
-            for track in range(tracks):
+            for track in range(audio_tracks):
                 text += '   - Track #{}\n'.format(track)
                 text += '     - codec: {}\n'.format(inp.audio_streams[track]['codec'])
                 text += '     - samplerate: {}\n'.format(
                     inp.audio_streams[track]['samplerate'])
                 text += '     - bitrate: {}\n'.format(inp.audio_streams[track]['bitrate'])
+                text += '     - lang: {}\n'.format(inp.audio_streams[track]['lang'])
 
             sub_tracks = len(inp.subtitle_streams)
             if(sub_tracks > 0):
                 text += ' - subtitle tracks: {}\n'.format(sub_tracks)
-                for track in range(tracks):
+                for track in range(sub_tracks):
                     text += '   - Track #{}\n'.format(track)
+                    text += '     - codec: {}\n'.format(inp.subtitle_streams[track]['codec'])
                     text += '     - lang: {}\n'.format(inp.subtitle_streams[track]['lang'])
 
             if(args.include_vfr):
@@ -90,8 +92,7 @@ def info(sys_args=None):
                 text = ''
                 fps_mode = ffmpeg.pipe(['-i', file, '-hide_banner', '-vf', 'vfrdet',
                     '-an', '-f', 'null', '-'])
-                fps_mode = clean_list(fps_mode.split('\n'), '\r\t')
-                fps_mode = fps_mode.pop()
+                fps_mode = fps_mode.strip()
 
                 if('VFR:' in fps_mode):
                     fps_mode = (fps_mode[fps_mode.index('VFR:'):]).strip()
@@ -108,4 +109,4 @@ def info(sys_args=None):
         print(text)
 
 if(__name__ == '__main__'):
-    info()
+    main()
