@@ -176,7 +176,7 @@ class Tester():
             sys.exit(1)
         sys.exit(0)
 
-def test(sys_args=None):
+def main(sys_args=None):
     parser = vanparse.ArgumentParser('test', 'version')
     parser = test_options(parser)
 
@@ -217,6 +217,28 @@ def test(sys_args=None):
             sys.exit(1)
     tester.run_test('version_tests', version_debug)
 
+    def subtitle_tests():
+        from auto_editor.render.subtitle import SubtitleParser
+        test = SubtitleParser()
+        test.contents = [
+            [0, 10, "A"],
+            [10, 20, "B"],
+            [20, 30, "C"],
+            [30, 40, "D"],
+            [40, 50, "E"],
+            [50, 60, "F"],
+        ]
+        speeds = [99999, 1]
+        chunks = [[0, 10, 1], [10, 20, 0], [20, 30, 1], [30, 40, 0], [40, 50, 1],
+            [50, 60, 0]]
+        test.edit(chunks, speeds)
+
+        if(test.contents != [[0, 10, "A"], [10, 20, "C"], [20, 30, "E"]]):
+            raise ValueError('Incorrect subtitle results.')
+
+
+    tester.run_test('subtitle_tests', subtitle_tests)
+
     def info_tests():
         run_program(['info', 'example.mp4'])
         run_program(['info', 'resources/man_on_green_screen.mp4'])
@@ -281,11 +303,19 @@ def test(sys_args=None):
 
     def backwards_range_test():
         run_program(['example.mp4', '--edit', 'none', '--cut_out', '-5secs,end'])
+        run_program(['example.mp4', '--edit', 'all', '--add_in', '-5secs,end'])
     tester.run_test('backwards_range_test', backwards_range_test, description='''
         Cut out the last 5 seconds of a media file by using negative number in the
         range.
         ''')
 
+    def cut_out_test():
+        run_program(['example.mp4', '--edit', 'none', '--video_speed', '2',
+            '--silent_speed', '3', '--cut_out', '2secs,10secs'])
+        run_program(['example.mp4', '--edit', 'all', '--video_speed', '2',
+            '--add_in', '2secs,10secs'])
+    tester.run_test('cut_out_test', cut_out_test)
+
     def gif_test():
         run_program(['resources/man_on_green_screen.gif', '--edit', 'none'])
     tester.run_test('gif_test', gif_test, description='''
@@ -464,4 +494,4 @@ def test(sys_args=None):
     tester.end()
 
 if(__name__ == '__main__'):
-    test()
+    main()
